@@ -1,8 +1,5 @@
 package Data::Google::Visualization::DataTable;
-BEGIN {
-  $Data::Google::Visualization::DataTable::VERSION = '0.10';
-}
-
+$Data::Google::Visualization::DataTable::VERSION = '0.11';
 use strict;
 use warnings;
 
@@ -16,7 +13,7 @@ Data::Google::Visualization::DataTable - Easily create Google DataTable objects
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
@@ -460,6 +457,7 @@ sub add_rows {
 				# We're going to have to retrieve them ourselves
 				} else {
 					my @initial_date_digits;
+					my $has_milliseconds;
 
 					# Epoch timestamp
 					if (! ref( $cell->{'v'} ) ) {
@@ -473,14 +471,18 @@ sub add_rows {
 						my $dt = $cell->{'v'};
 						@initial_date_digits = (
 							$dt->year, ( $dt->mon - 1 ), $dt->day,
-							$dt->hour, $dt->min, $dt->sec
+							$dt->hour, $dt->min, $dt->sec,
 						);
+						if ( $dt->millisecond ) {
+							$has_milliseconds++;
+							push( @initial_date_digits, $dt->millisecond );
+						}
 
 					} elsif ( $cell->{'v'}->isa('Time::Piece') ) {
 						my $tp = $cell->{'v'};
 						@initial_date_digits = (
 							$tp->year, $tp->_mon, $tp->mday,
-							$tp->hour, $tp->min, $tp->sec
+							$tp->hour, $tp->min, $tp->sec,
 						);
 
 					} else {
@@ -491,8 +493,12 @@ sub add_rows {
 						@date_digits = @initial_date_digits[ 0 .. 2 ];
 					} elsif ( $type eq 'datetime' ) {
 						@date_digits = @initial_date_digits[ 0 .. 5 ];
+						push( @date_digits, $initial_date_digits[6] )
+							if $has_milliseconds;
 					} else { # Time of day
 						@date_digits = @initial_date_digits[ 3 .. 5 ];
+						push( @date_digits, $initial_date_digits[6] )
+							if $has_milliseconds;
 					}
 				}
 
@@ -815,4 +821,4 @@ This program is free software; you can redistribute it and/or modify it under th
 
 =cut
 
-1;
\ No newline at end of file
+1;
